@@ -1,6 +1,6 @@
 # ###############################################################################
 #
-# Copyright (C) 2012-2020, Michele Cappellari
+# Copyright (C) 2012-2021, Michele Cappellari
 # E-mail: michele.cappellari_at_physics.ox.ac.uk
 #
 # Updated versions of the software are available from my web page
@@ -68,6 +68,7 @@
 #       V3.0.14: Fixed incorrect plot ranges due to a Matplotlib change.
 #           Thanks to Davide Bevacqua (unibo.it) for the report.
 #           MC, Oxford, 22 January 2021
+#       Vx.x.x: Additional changes are documented in the CHANGELOG of the LtsFit package.
 #
 #------------------------------------------------------------------------------
 
@@ -203,8 +204,8 @@ def _fast_algorithm(x, y, z, sigx, sigy, sigz, h):
 
 class lts_planefit:
     """
-    LTS_PLANEFIT
-    ------------
+    lts_planefit
+    ============
 
     Purpose
     -------
@@ -222,10 +223,9 @@ class lts_planefit:
     scatter in the relation.
 
     Outliers are iteratively clipped using the extremely robust
-    FAST-LTS technique by `Rousseeuw & van Driessen (2006)
-    <http://dx.doi.org/10.1007/s10618-005-0024-4>`_
-    (See also `Rousseeuw 1987)
-    <http://books.google.co.uk/books?id=woaH_73s-MwC&pg=PA15>`_
+    FAST-LTS technique by
+    `Rousseeuw & van Driessen (2006) <http://doi.org/10.1007/s10618-005-0024-4>`_
+    See also `Rousseeuw (1987) <http://books.google.co.uk/books?id=woaH_73s-MwC&pg=PA15>`_
 
     Calling Sequence
     ----------------
@@ -253,7 +253,7 @@ class lts_planefit:
     frac:
         fractions of values to include in the LTS stage.
         Up to a fraction "frac" of the values can be outliers.
-        One must have 0.5 < frac < 1  (default frac=0.5).
+        One must have 0.5 <= frac <= 1  (default frac=0.5).
 
         NOTE: Set frac=1, to turn off outliers detection.
     pivotx, pivoty:
@@ -263,7 +263,7 @@ class lts_planefit:
 
         pivotx, pivoty are called x_0, y_0 in eq.(7) of Cappellari et al. (2013)
         Use of these keywords is *strongly* recommended, and suggested
-        values are ``pivotx ~ np.mean(x), pivoty ~ np.mean(y)``.
+        values are ``pivotx=np.median(x), pivoty=np.median(y)``.
         This keyword is important to reduce the covariance between a, b and c.
     plot:
         if True a plot of the fit is produced.
@@ -291,6 +291,7 @@ class lts_planefit:
     p.sig_int_err:
         1*sigma formal error on sig_int.
 
+    ###########################################################################
 
     """
 
@@ -394,6 +395,9 @@ class lts_planefit:
         if pivotx or pivoty:
             print('z = a + b*(x - pivotx) + c*(y - pivoty)')
             print('with pivotx = %.4g & pivoty = %.4g' % (pivotx, pivoty))
+        else:
+            print('WARNING: pivotx=0 or pivoty=0. Using `pivotx` and `pivoty` keywords is always reccomended')
+
         print('##########################################################')
 
         print('seconds %.2f' % (clock() - t))
